@@ -20,9 +20,9 @@ def load_local_file(filename):
 """
     Main
 """
-async def main(func, controller):
+async def main(func, controller:sf.Controller):
 
-    asyncio.create_task( controller.start_loops() )
+    task_controller = asyncio.create_task( controller.start_loops() )
     os.makedirs('.sf', exist_ok=True)
 
     await func()      
