@@ -59,7 +59,11 @@ class Task:
         else:
             self.uid = ""
 
-        self.quiet = True
+        if "quiet" in kwargs.keys():
+            self.quiet  = kwargs["quiet"]
+        else:
+            self.quiet = True
+
         self.hash = ""
         self.return_file = ""
         self.props = {}
